@@ -21,7 +21,7 @@ use Template::Provider;
 use Text::Abbrev;
 use Text::Wrap qw{ wrap };
 
-our $VERSION = '0.027_04';
+our $VERSION = '0.028';
 
 sub new {
     my ($class, @args) = @_;
@@ -479,14 +479,6 @@ Astro::App::Satpass2::Format::Template - Format Astro::App::Satpass2 output as t
 	 time => $time,
      } );
 
-=head1 NOTICE
-
-This is alpha code. It has been tested on my box, but has limited
-exposure to the wild. Also, the public interface may not be completely
-stable, and may change if needed to support
-L<Astro::App::Satpass2|Astro::App::Satpass2>. I will try to document any
-incompatible changes.
-
 =head1 DETAILS
 
 This class is intended to perform output formatting for
